# 开始使用

```{toctree}
:maxdepth: 2
:hidden:

async-callable
create-bot
event-process
msg-action
action-echo
event-preprocess
use-plugin
use-session
```

```{admonition} 先决条件
:class: caution
melobot 是基于 asyncio 的开发框架，我们假设你已经具备异步编程的相关能力。
```

```{admonition} 提示
:class: tip

- 本文档有**超多交叉引用链接**，善用浏览器的“回退按钮”，它能让你回到跳转前的位置。
- 如果文档没有告诉你一个类、方法、函数该从何处导入，请**将光标悬浮在这个类、方法、函数的引用链接**上，随后你会看到它在哪个模块。
- 你**最不需要担心的就是文档的友好程度，因为我们有意愿、更有信心讲明白这些有趣的东西** :)
```

即使你从来没有接触过机器人开发，接下来的教程也将以浅显易懂的方式，带你使用 melobot 进行机器人开发。

点击页面右下角的“Next”开始吧！
